SRCS	=\
	w3win.cc\
	w3man.cc\
	w3form.cc\
	w3style.c\
	w3alert.cc\
	HText.cc\
	HTML.cc\
	HTTP.cc\
	HTAccess.c\
	HTTelnet.c\
	HTFormat.c\
	HTFTP.c\
	HTWriter.c\
	HTNews.c\
	HTGopher.c

OBJS	=\
	w3win.o\
	w3man.o\
	w3form.o\
	w3style.o\
	w3alert.o\
	HText.o\
	HTML.o\
	HTTP.o\
	HTAccess.o\
	HTTelnet.o\
	HTFormat.o\
	HTFTP.o\
	HTWriter.o\
	HTNews.o\
	HTGopher.o

INC_W	= ./www/lib
INC_T	= ../task
INC_A	= ../tscr
INC_E	= ../tyui

LIB_W	= ./www/lib/obj/libWWW.a
LIBS	= ../task/libscrn.a ../task/libtask.a ../term/libtcaps.a
LIB_A	= ../tscr/libappl.a
LIB_E	= ../tyui/libedit.a

LIB	= libw3t.a

# Solaris sparc
#SYSTEM	= -DSOLARIS_SPARC
# Solaris x86
#SYSTEM	= -DSOLARIS_X86
# Sinix-N SNI 5.42
#SYSTEm = -DSINIX

#CC	= gcc
#CC	= egcc

#DMALLOC = -DDMALLOC
#LDMALLOC = -ldmalloc -ldmalloc++

CFLAGS	= -O2 -g -fpic $(SYSTEM) $(DMALLOC) -Wall -Wno-unused -I$(INC_W) -I$(INC_T) -I$(INC_A) -I$(INC_E)
#CFLAGS	= -DMALLOC_DEBUG -g -pipe $(SYSTEM) -Wall -Wno-unused -I$(INC_W) -I$(INC_T) -I$(INC_A) -I$(INC_E)
#MDEBUG	= /usr/local/lib/memdebug.a

.SUFFIXES: .o .cc

.cc.o:
	$(CC) $(CFLAGS) -c $<

.c.o:
	$(CC) $(CFLAGS) -c $<

all:	$(LIB) $(LIB_W)

wtest:	main.o $(LIB) $(LIB_W) $(LIB_A) $(LIBS) $(LIB_E)
	$(CC) $(CFLAGS) -o wtest main.o $(LIB) $(LIB_W) $(LIB_E) $(LIB_A) $(LIBS) $(MDEBUG) -lm $(LDMALLOC)

lib:	$(LIB)

$(LIB): $(OBJS)
	-rm -f $@
	ar rv $@ $(OBJS)
	ranlib $@

$(LIB_W):
	cd www ; export MAKEFLAGS=''; pmake


clean:
	rm -f *.o *.a *core* wtest
	cd www; export MAKEFLAGS=''; pmake clean

hash:
	../task/hashextract $(SRCS) main.cc | sort -u > _hashcode.h
	cmp _hashcode.h hashcode.h || cp _hashcode.h hashcode.h

depend:
	make hash
	makedepend -Y -- $(CFLAGS) -- $(SRCS) main.cc 2>/dev/null

# DO NOT DELETE

w3win.o: ./www/lib/HTTP.h ./www/lib/HTAccess.h ./www/lib/HTList.h
w3win.o: ./www/lib/HTUtils.h ./www/lib/HTString.h ./www/lib/HTAnchor.h
w3win.o: ./www/lib/HTAtom.h ./www/lib/HTFormat.h ./www/lib/HTStream.h
w3win.o: ./www/lib/HTAAUtil.h ./www/lib/tcp.h ./www/lib/HTAABrow.h
w3win.o: ./www/lib/HTAssoc.h ../tscr/program.h ../task/task.h ../task/list.h
w3win.o: ../task/message.h hashcode.h ../task/collect.h ../task/keytask.h
w3win.o: ../task/keycodes.h ../task/point.h ../tscr/keymap.h ../task/langs.h
w3win.o: ../tscr/yterm.h ../tscr/window.h ../tscr/getobj.h ../task/screen.h
w3win.o: ../tscr/menu.h ../tscr/listbox.h ../task/array.h ../tscr/filebox.h
w3win.o: ../tscr/modal.h ../tscr/dialog.h ../tscr/visual.h ../tscr/dir.h
w3win.o: ../tscr/filepath.h ../tscr/status.h w3man.h w3private.h
w3win.o: ./www/lib/HTTCP.h ./www/lib/HTParse.h ./www/lib/HTML.h
w3win.o: ./www/lib/HTMLPDTD.h ./www/lib/SGML.h ./www/lib/HTFWriter.h
w3win.o: ./www/lib/HTMLGen.h ./www/lib/HTFile.h ./www/lib/HTDirBrw.h
w3win.o: ./www/lib/HTFTP.h ./www/lib/HTChunk.h ./www/lib/HTRules.h
w3win.o: ./www/lib/HTError.h ./www/lib/HTAlert.h ./www/lib/HTStyle.h
w3win.o: ./www/lib/HTPlain.h ./www/lib/HText.h w3style.h ../tyui/yui.h
w3win.o: w3win.h
w3man.o: ./www/lib/HTError.h ./www/lib/HTAccess.h ./www/lib/HTList.h
w3man.o: ./www/lib/HTUtils.h ./www/lib/HTString.h ./www/lib/HTAnchor.h
w3man.o: ./www/lib/HTAtom.h ./www/lib/HTFormat.h ./www/lib/HTStream.h
w3man.o: ./www/lib/HTAAUtil.h ./www/lib/tcp.h ./www/lib/HTAABrow.h
w3man.o: ./www/lib/HTAssoc.h rw.h ../task/reg_expr.h ../tscr/dir.h
w3man.o: ../tscr/filepath.h ../task/collect.h ../tscr/program.h
w3man.o: ../task/task.h ../task/list.h ../task/message.h hashcode.h
w3man.o: ../task/keytask.h ../task/keycodes.h ../task/point.h
w3man.o: ../tscr/keymap.h ../task/langs.h ../tscr/window.h ../tscr/getobj.h
w3man.o: ../task/screen.h w3man.h
w3form.o: ../task/keycodes.h w3private.h ./www/lib/HTUtils.h
w3form.o: ./www/lib/HTString.h ./www/lib/HTFormat.h ./www/lib/HTStream.h
w3form.o: ./www/lib/HTAtom.h ./www/lib/HTList.h ./www/lib/HTAccess.h
w3form.o: ./www/lib/HTAnchor.h ./www/lib/HTAAUtil.h ./www/lib/tcp.h
w3form.o: ./www/lib/HTAABrow.h ./www/lib/HTAssoc.h ./www/lib/HTTCP.h
w3form.o: ./www/lib/HTParse.h ./www/lib/HTML.h ./www/lib/HTMLPDTD.h
w3form.o: ./www/lib/SGML.h ./www/lib/HTFWriter.h ./www/lib/HTMLGen.h
w3form.o: ./www/lib/HTFile.h ./www/lib/HTDirBrw.h ./www/lib/HTFTP.h
w3form.o: ./www/lib/HTChunk.h ./www/lib/HTRules.h ./www/lib/HTError.h
w3form.o: ./www/lib/HTAlert.h ./www/lib/HTTP.h ./www/lib/HTStyle.h
w3form.o: ./www/lib/HTPlain.h ./www/lib/HText.h w3style.h ../task/point.h
w3form.o: ../task/collect.h ../tscr/listbox.h ../task/array.h
w3form.o: ../tscr/window.h ../tscr/getobj.h ../task/screen.h ../task/langs.h
w3form.o: ../tscr/keymap.h ../tyui/yui.h hashcode.h w3win.h ../tscr/dialog.h
w3form.o: ../tscr/visual.h w3table.h ../task/list.h
w3style.o: ./www/lib/HTStyle.h ./www/lib/HTUtils.h ./www/lib/HTString.h
w3style.o: ./www/lib/HTFormat.h ./www/lib/HTStream.h ./www/lib/HTAtom.h
w3style.o: ./www/lib/HTList.h ./www/lib/HTAccess.h ./www/lib/HTAnchor.h
w3style.o: ./www/lib/HTAAUtil.h ./www/lib/tcp.h ./www/lib/HTAABrow.h
w3style.o: ./www/lib/HTAssoc.h ./www/lib/HTML.h ./www/lib/HTMLPDTD.h
w3style.o: ./www/lib/SGML.h w3style.h
w3alert.o: ./www/lib/HTAlert.h ./www/lib/HTUtils.h ./www/lib/HTString.h
w3alert.o: ../tscr/program.h ../task/task.h ../task/list.h ../task/message.h
w3alert.o: hashcode.h ../task/collect.h ../task/keytask.h ../task/keycodes.h
w3alert.o: ../task/point.h ../tscr/keymap.h ../task/langs.h ../tscr/dialog.h
w3alert.o: ../tscr/window.h ../tscr/getobj.h ../task/screen.h
w3alert.o: ../tscr/visual.h ../tscr/listbox.h ../task/array.h
HText.o: ../task/term.h w3private.h ./www/lib/HTUtils.h ./www/lib/HTString.h
HText.o: ./www/lib/HTFormat.h ./www/lib/HTStream.h ./www/lib/HTAtom.h
HText.o: ./www/lib/HTList.h ./www/lib/HTAccess.h ./www/lib/HTAnchor.h
HText.o: ./www/lib/HTAAUtil.h ./www/lib/tcp.h ./www/lib/HTAABrow.h
HText.o: ./www/lib/HTAssoc.h ./www/lib/HTTCP.h ./www/lib/HTParse.h
HText.o: ./www/lib/HTML.h ./www/lib/HTMLPDTD.h ./www/lib/SGML.h
HText.o: ./www/lib/HTFWriter.h ./www/lib/HTMLGen.h ./www/lib/HTFile.h
HText.o: ./www/lib/HTDirBrw.h ./www/lib/HTFTP.h ./www/lib/HTChunk.h
HText.o: ./www/lib/HTRules.h ./www/lib/HTError.h ./www/lib/HTAlert.h
HText.o: ./www/lib/HTTP.h ./www/lib/HTStyle.h ./www/lib/HTPlain.h
HText.o: ./www/lib/HText.h w3style.h ../task/point.h ../task/collect.h
HText.o: ../tscr/listbox.h ../task/array.h ../tscr/window.h ../tscr/getobj.h
HText.o: ../task/keycodes.h ../task/screen.h ../task/langs.h ../tscr/keymap.h
HText.o: ../tyui/yui.h hashcode.h w3win.h ../tscr/dialog.h ../tscr/visual.h
HText.o: w3table.h ../task/list.h
HTML.o: ./www/lib/HTUtils.h ./www/lib/HTString.h ./www/lib/HTChunk.h
HTML.o: ./www/lib/HText.h ./www/lib/HTAnchor.h ./www/lib/HTList.h
HTML.o: ./www/lib/HTAtom.h ./www/lib/HTFormat.h ./www/lib/HTStream.h
HTML.o: ./www/lib/HTAccess.h ./www/lib/HTAAUtil.h ./www/lib/tcp.h
HTML.o: ./www/lib/HTAABrow.h ./www/lib/HTAssoc.h ./www/lib/HTStyle.h
HTML.o: ./www/lib/HTML.h ./www/lib/HTMLPDTD.h ./www/lib/SGML.h
HTML.o: ./www/lib/HTMLGen.h ./www/lib/HTParse.h
HTTP.o: ./www/lib/HTParse.h ./www/lib/HTUtils.h ./www/lib/HTString.h
HTTP.o: ./www/lib/tcp.h ./www/lib/HTTCP.h ./www/lib/HTAccess.h
HTTP.o: ./www/lib/HTList.h ./www/lib/HTAnchor.h ./www/lib/HTAtom.h
HTTP.o: ./www/lib/HTFormat.h ./www/lib/HTStream.h ./www/lib/HTAAUtil.h
HTTP.o: ./www/lib/HTAABrow.h ./www/lib/HTAssoc.h ./www/lib/HTAlert.h
HTTP.o: ./www/lib/HTMIME.h ./www/lib/HTML.h ./www/lib/HTMLPDTD.h
HTTP.o: ./www/lib/SGML.h ./www/lib/HTInit.h ./www/lib/HTTee.h
HTTP.o: ./www/lib/HTFWriter.h ./www/lib/HTError.h ./www/lib/HTChunk.h
HTTP.o: ./www/lib/HTTP.h rw.h ../tscr/program.h ../task/task.h ../task/list.h
HTTP.o: ../task/message.h hashcode.h ../task/collect.h ../task/keytask.h
HTTP.o: ../task/keycodes.h ../task/point.h ../tscr/keymap.h ../task/langs.h
HTTP.o: w3win.h ../tscr/dialog.h ../tscr/window.h ../tscr/getobj.h
HTTP.o: ../task/screen.h ../tscr/visual.h
HTAccess.o: ./www/lib/HTAccess.h ./www/lib/HTList.h ./www/lib/HTUtils.h
HTAccess.o: ./www/lib/HTString.h ./www/lib/HTAnchor.h ./www/lib/HTAtom.h
HTAccess.o: ./www/lib/HTFormat.h ./www/lib/HTStream.h ./www/lib/HTAAUtil.h
HTAccess.o: ./www/lib/tcp.h ./www/lib/HTAABrow.h ./www/lib/HTAssoc.h
HTAccess.o: ./www/lib/HTParse.h ./www/lib/HTML.h ./www/lib/HTMLPDTD.h
HTAccess.o: ./www/lib/SGML.h ./www/lib/HTRules.h ./www/lib/HText.h
HTAccess.o: ./www/lib/HTStyle.h ./www/lib/HTAlert.h ./www/lib/HTFWriter.h
HTAccess.o: ./www/lib/HTTee.h ./www/lib/HTError.h ./www/lib/HTFile.h
HTAccess.o: ./www/lib/HTDirBrw.h ./www/lib/HTFTP.h ./www/lib/HTChunk.h
HTTelnet.o: ./www/lib/HTParse.h ./www/lib/HTUtils.h ./www/lib/HTString.h
HTTelnet.o: ./www/lib/HTAnchor.h ./www/lib/HTList.h ./www/lib/HTAtom.h
HTTelnet.o: ./www/lib/HTFormat.h ./www/lib/HTStream.h ./www/lib/HTAccess.h
HTTelnet.o: ./www/lib/HTAAUtil.h ./www/lib/tcp.h ./www/lib/HTAABrow.h
HTTelnet.o: ./www/lib/HTAssoc.h ./www/lib/HTTP.h ./www/lib/HTFile.h
HTTelnet.o: ./www/lib/HTML.h ./www/lib/HTMLPDTD.h ./www/lib/SGML.h
HTTelnet.o: ./www/lib/HTDirBrw.h ./www/lib/HTFTP.h ./www/lib/HTChunk.h
HTTelnet.o: ./www/lib/HTAlert.h ./www/lib/HTTelnet.h
HTFormat.o: ./www/lib/HTFormat.h ./www/lib/HTUtils.h ./www/lib/HTString.h
HTFormat.o: ./www/lib/HTStream.h ./www/lib/HTAtom.h ./www/lib/HTList.h
HTFormat.o: ./www/lib/HTAccess.h ./www/lib/HTAnchor.h ./www/lib/HTAAUtil.h
HTFormat.o: ./www/lib/tcp.h ./www/lib/HTAABrow.h ./www/lib/HTAssoc.h
HTFormat.o: ./www/lib/HTML.h ./www/lib/HTMLPDTD.h ./www/lib/SGML.h
HTFormat.o: ./www/lib/HTAlert.h ./www/lib/HTInit.h ./www/lib/HTFWriter.h
HTFormat.o: ./www/lib/HTPlain.h ./www/lib/HTMLGen.h ./www/lib/HTTCP.h
HTFormat.o: ./www/lib/HTGuess.h ./www/lib/HTError.h rw.h
HTFTP.o: ./www/lib/tcp.h ./www/lib/HTParse.h ./www/lib/HTUtils.h
HTFTP.o: ./www/lib/HTString.h ./www/lib/HTTCP.h ./www/lib/HTAccess.h
HTFTP.o: ./www/lib/HTList.h ./www/lib/HTAnchor.h ./www/lib/HTAtom.h
HTFTP.o: ./www/lib/HTFormat.h ./www/lib/HTStream.h ./www/lib/HTAAUtil.h
HTFTP.o: ./www/lib/HTAABrow.h ./www/lib/HTAssoc.h ./www/lib/HTFile.h
HTFTP.o: ./www/lib/HTML.h ./www/lib/HTMLPDTD.h ./www/lib/SGML.h
HTFTP.o: ./www/lib/HTDirBrw.h ./www/lib/HTFTP.h ./www/lib/HTChunk.h
HTFTP.o: ./www/lib/HTBTree.h ./www/lib/HTAlert.h ./www/lib/HTError.h rw.h
HTWriter.o: ./www/lib/HTWriter.h ./www/lib/HTStream.h ./www/lib/HTUtils.h
HTWriter.o: ./www/lib/HTString.h ./www/lib/tcp.h rw.h
HTNews.o: ./www/lib/HTNews.h ./www/lib/HTAccess.h ./www/lib/HTList.h
HTNews.o: ./www/lib/HTUtils.h ./www/lib/HTString.h ./www/lib/HTAnchor.h
HTNews.o: ./www/lib/HTAtom.h ./www/lib/HTFormat.h ./www/lib/HTStream.h
HTNews.o: ./www/lib/HTAAUtil.h ./www/lib/tcp.h ./www/lib/HTAABrow.h
HTNews.o: ./www/lib/HTAssoc.h ./www/lib/HTML.h ./www/lib/HTMLPDTD.h
HTNews.o: ./www/lib/SGML.h ./www/lib/HTParse.h ./www/lib/HTAlert.h
HTNews.o: ./www/lib/HTError.h rw.h
HTGopher.o: ./www/lib/tcp.h ./www/lib/HTParse.h ./www/lib/HTUtils.h
HTGopher.o: ./www/lib/HTString.h ./www/lib/HTTCP.h ./www/lib/HTAccess.h
HTGopher.o: ./www/lib/HTList.h ./www/lib/HTAnchor.h ./www/lib/HTAtom.h
HTGopher.o: ./www/lib/HTFormat.h ./www/lib/HTStream.h ./www/lib/HTAAUtil.h
HTGopher.o: ./www/lib/HTAABrow.h ./www/lib/HTAssoc.h ./www/lib/HTIcons.h
HTGopher.o: ./www/lib/HTError.h ./www/lib/HTFile.h ./www/lib/HTML.h
HTGopher.o: ./www/lib/HTMLPDTD.h ./www/lib/SGML.h ./www/lib/HTDirBrw.h
HTGopher.o: ./www/lib/HTFTP.h ./www/lib/HTChunk.h ./www/lib/HTGopher.h rw.h
main.o: ../task/term.h ../tscr/program.h ../task/task.h ../task/list.h
main.o: ../task/message.h hashcode.h ../task/collect.h ../task/keytask.h
main.o: ../task/keycodes.h ../task/point.h ../tscr/keymap.h ../task/langs.h
main.o: ../tscr/menu.h ../tscr/listbox.h ../task/array.h ../tscr/window.h
main.o: ../tscr/getobj.h ../task/screen.h ../tscr/yterm.h ../tscr/filebox.h
main.o: ../tscr/modal.h ../tscr/dialog.h ../tscr/visual.h ../tscr/dir.h
main.o: ../tscr/filepath.h w3win.h
